﻿using System;
using System.Data;

namespace MyADO {
    class Program {
        static void Main(string[] args) {
            // Create DataSet ds & DataTable "Person"
            DataSet ds = new DataSet("PersonContacts");
            DataTable personTable = new DataTable("Person");
            // Define the column "ID" and its properties
            DataColumn col = new DataColumn();
            col.DataType = typeof(System.Int64);
            col.ColumnName = "ID";
            col.ReadOnly = true;
            col.Unique = true;
            col.AutoIncrement = true;
            col.AutoIncrementSeed = 1;
            col.AutoIncrementStep = 1;
            // Add the column to the table and set the PK (Primary Key)
            personTable.Columns.Add(col);
            personTable.PrimaryKey = new DataColumn[] { col };
            // Define the other column and add it to the table
            col = new DataColumn();
            col.DataType = typeof(string);
            col.ColumnName = "FirstName";
            personTable.Columns.Add(col);
            // Define the other column and add it to the table
            col = new DataColumn();
            col.DataType = typeof(string);
            col.ColumnName = "LastName";
            personTable.Columns.Add(col);
            // Add the table to the DataSet
            ds.Tables.Add(personTable);

            // Create DataTable "Contact"
            DataTable contactTable = new DataTable("Contact");
            // Define the column "ID" and its properties
            col = new DataColumn();
            col.DataType = typeof(System.Int64);
            col.ColumnName = "ID";
            col.ReadOnly = true;
            col.Unique = true;
            col.AutoIncrement = true;
            col.AutoIncrementSeed = 1;
            col.AutoIncrementStep = 1;
            // Add the column to the table and set the PK (Primary Key)
            contactTable.Columns.Add(col);
            contactTable.PrimaryKey = new DataColumn[] { col };
            // Define the other column and add it to the table
            col = new DataColumn();
            col.DataType = typeof(string);
            col.ColumnName = "FirstName";
            contactTable.Columns.Add(col);
            // Define the other column and add it to the table
            col = new DataColumn();
            col.DataType = typeof(string);
            col.ColumnName = "LastName";
            contactTable.Columns.Add(col);
            // Define the other column and add it to the table
            col = new DataColumn();
            col.DataType = typeof(string);
            col.ColumnName = "NickName";
            contactTable.Columns.Add(col);
            // Define the other column and add it to the table
            col = new DataColumn();
            col.DataType = typeof(string);
            col.ColumnName = "Email";
            contactTable.Columns.Add(col);
            // Define the other column and add it to the table
            col = new DataColumn();
            col.DataType = typeof(string);
            col.ColumnName = "Phone";
            contactTable.Columns.Add(col);
            // Define the column "PersonID" and add it to the table
            col = new DataColumn();
            col.DataType = typeof(System.Int64);
            col.ColumnName = "PersonID";
            contactTable.Columns.Add(col);

            // Add the table to the DataSet
            ds.Tables.Add(contactTable);

            // Define the relationship
            DataColumn parentCol = ds.Tables["Person"].Columns["ID"];
            DataColumn childCol = ds.Tables["Contact"].Columns["PersonID"];
            DataRelation rel = new DataRelation("PersonHasContacts",
                parentCol, childCol);
            ds.Relations.Add(rel);

            // Data operation: add a data to the table "Person"
            // Define a new row & its values
            DataRow personRow = personTable.NewRow();
            //personRow["FirstName"] = "Wolfgang";
            personRow[1] = "Wolfgang";
            personRow["LastName"] = "Beer";
            // Add the row to the table
            personTable.Rows.Add(personRow);

            // Data operation: add a data to the table "Contact"
            // Define a new row & its values
            DataRow contactRow = contactTable.NewRow();
            contactRow["FirstName"] = "Wolfgang";
            contactRow["LastName"] = "Beer";
            contactRow["Phone"] = "08123456789";
            contactRow["PersonID"] = (long)personRow["ID"]; // Defines a relation
                                                            // Add the row to the table
            contactTable.Rows.Add(contactRow);
            // Accept the changes permanently, if there's no errors
            if (ds.HasErrors) {
                ds.RejectChanges();
            } else {
                ds.AcceptChanges();
            }

            // Access the DataSet
            Console.WriteLine("Table: Person");
            Console.WriteLine(" ID  FirstName   LastName");
            foreach (DataRow person in personTable.Rows) {
                Console.WriteLine("{0,3} {1,10} {2,10}",
                    person["ID"], person["FirstName"], person["LastName"]);
            }
            // Other method
            Console.WriteLine("\nTable: Contact");
            Console.WriteLine(" FirstName   LastName       Phone   PersonID");
            foreach (DataRow contact in personRow.GetChildRows("PersonHasContacts")) {
                Console.WriteLine("{0,10} {1,10} {2,10} {3,10}",
                    contact["FirstName"], contact["LastName"],
                    contact["Phone"], contact["PersonID"]);
            }

            // DataRowVersion example
            Console.WriteLine("\nDataRowVersion example");
            bool hasOriginal =
                personRow.HasVersion(DataRowVersion.Original);
            if (hasOriginal) {
                string originalName = (string) personRow["LastName", DataRowVersion.Original];
                Console.WriteLine("LastName: " + originalName);
            }
        }
    }
}
